/*
  kbalm.cpp - Main window for KBalm

  Copyright 2004 by Richard Smith <kde@metafoo.co.uk>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
*/

#include "kbalm.h"

#include "aiplayer.h"
#include "board.h"
#include "boardwidget.h"
#include "game.h"
#include "humanplayer.h"
#include "player.h"
#include "prefs.h"
#include "scorepanel.h"

#include <kapplication.h>
#include <kiconloader.h>
#include <klocale.h>
#include <kconfig.h>
#include <kmenubar.h>
#include <kpopupmenu.h>
#include <kaction.h>
#include <kstatusbar.h>
#include <kstdaction.h>
#include <kstdgameaction.h>

#include <qhbox.h>

KBalm::KBalm()
	: _game(0)
{
/*	statusBar()->insertItem( i18n("Player 1's turn"), 1, 1 );
	statusBar()->setItemAlignment( 1, AlignVCenter | AlignLeft );*/
	
	initKAction();
	
	newGame();
}

KBalm::~KBalm()
{
}

void KBalm::initKAction()
{
	KStdGameAction::gameNew( this, SLOT( newGame() ), actionCollection() );
	//act_demo = KStdGameAction::demo( this, SLOT( startDemo() ), actionCollection() );
	KStdGameAction::quit( this, SLOT( close() ), actionCollection() );
	//undoAction = KStdGameAction::undo( this, SLOT( undo() ), actionCollection() );
	
	(void)new KAction( i18n("Move Left"),  Key_Left,  this, SIGNAL( moveLeft() ),      actionCollection(), "left");
	(void)new KAction( i18n("Move Right"), Key_Right, this, SIGNAL( moveRight() ),     actionCollection(), "right");
	(void)new KAction( i18n("Move Up"),    Key_Up,    this, SIGNAL( moveUp() ),        actionCollection(), "up");
	(void)new KAction( i18n("Move Down"),  Key_Down,  this, SIGNAL( moveDown() ),      actionCollection(), "down");
	(void)new KAction( i18n("Rotate"),     Key_Space, this, SIGNAL( selectCurrent() ), actionCollection(), "rotate");
	
	setupGUI( Keys | StatusBar | Create );
}

void KBalm::newGame()
{
	Balm::Game::Params params( this, "_game" );
	params.addPlayer( new KBalmHumanPlayer( this, 0 ) );
//	params.addPlayer( new KBalmAI::Player( 0 ) );
	params.addPlayer( new KBalmAI::Player( 1 ) );
//	params.addPlayer( new KBalmAI::Player( 2 ) );
//	params.addPlayer( new KBalmAI::Player( 3 ) );

	std::auto_ptr<Balm::Game> game( new Balm::Game( params ) );
	
	QHBox *hbox = new QHBox( this, "central_hbox" );
	Balm::BoardWidget *boardWidget = new Balm::BoardWidget( hbox, &game->board(), "board_widget" );
	new KBalmScorePanel( hbox, game.get(), "score_panel" );
	std::auto_ptr<QWidget> old( centralWidget() );
	
	setCentralWidget( hbox );
	centralWidget()->show();
	
	connect( this, SIGNAL( moveLeft() ), boardWidget, SLOT( moveLeft() ) );
	connect( this, SIGNAL( moveRight() ), boardWidget, SLOT( moveRight() ) );
	connect( this, SIGNAL( moveUp() ), boardWidget, SLOT( moveUp() ) );
	connect( this, SIGNAL( moveDown() ), boardWidget, SLOT( moveDown() ) );
	connect( this, SIGNAL( selectCurrent() ), boardWidget, SLOT( selectCurrent() ) );
	
	connect( boardWidget, SIGNAL( nodeSelected(int,int) ), this, SIGNAL( nodeSelected(int,int) ) );
	
	_game = game;
}

void KBalm::undo()
{
}

#include "kbalm.moc"
//kate: indent-mode: csands;
