/*
  scorepanel.cpp - widget displaying balm scores
  
  Copyright 2004 by Richard Smith <kde@metafoo.co.uk>
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
*/

#include "scorepanel.h"

#include "board.h"
#include "game.h"
#include "player.h"
#include "pixmapcache.h"

#include <klocale.h>

#include <qhbox.h>
#include <qlabel.h>
#include <qpixmap.h>
#include <qstring.h>

KBalmScorePanel::KBalmScorePanel( QWidget *parent, Balm::Game *game, const char *name )
	: QVBox( parent, name ), _game( game )
{
	KBalmPixmapCache cache;
	for ( int n = 0; n < game->players(); ++n )
	{
		Balm::Player *player = game->player( n );
		QWidget *box = new QHBox( this );
		QLabel *label = new QLabel( box );
		label->setPixmap( cache.pixmap( "pics/node_" + QString::number( player->number() + 1 ) + ".png" ) );
		
		QLabel *score = new QLabel( box );
		_labels.push_back( score );
	}
	
	scoreChanged();
	
	connect( &_game->board(), SIGNAL( scoreChanged() ), SLOT( scoreChanged() ) );
}

KBalmScorePanel::~KBalmScorePanel()
{
}
	
void KBalmScorePanel::scoreChanged()
{
	for ( int n = 0; n < _game->players(); ++n )
	{
		Balm::Player *player = _game->player( n );
		int score = _game->board().score( player->number() );
		_labels[n]->setText( i18n("One node controlled", "%n nodes controlled", score) );
	}
}
	
#include "scorepanel.moc"
//kate: indent-mode: csands;
